@@ -1,7 +1,6 @@
 module Test14 where 
 
 import Graphics.Rendering.Chart
-import Graphics.Rendering.Chart.Gtk
 import Data.Colour
 import Data.Colour.Names
 import Data.Accessor
@@ -43,6 +42,5 @@ chart lwidth = toRenderable layout
 main1 :: [String] -> IO (PickFn ())
 main1 ["small"]  = renderableToPNGFile (chart 0.25) 320 240 "test14_small.png"
 main1 ["big"]    = renderableToPNGFile (chart 0.25) 800 600 "test14_big.png"
-main1 _          = renderableToWindow  (chart 1.00) 640 480 >> return undefined
 
 main = getArgs >>= main1
