@@ -1,7 +1,6 @@
 module Test3 where
 
 import Graphics.Rendering.Chart
-import Graphics.Rendering.Chart.Gtk
 import Data.Time.LocalTime
 import Data.Colour
 import Data.Colour.Names
@@ -35,6 +34,5 @@ chart = toRenderable layout
 main1 :: [String] -> IO (PickFn ())
 main1 ["small"]  = renderableToPNGFile chart 320 240 "test3_small.png"
 main1 ["big"]    = renderableToPNGFile chart 800 600 "test3_big.png"
-main1 _          = renderableToWindow  chart 640 480 >> return undefined
 
 main = getArgs >>= main1
