@@ -1,7 +1,6 @@
 module Test5 where 
 
 import Graphics.Rendering.Chart
-import Graphics.Rendering.Chart.Gtk
 import Data.Colour
 import Data.Colour.Names
 import Data.Accessor
@@ -43,7 +42,6 @@ chart lwidth = toRenderable (layout 1001 (trial bits) :: Layout1 Double LogValue
 main1 :: [String] -> IO (PickFn ())
 main1 ["small"]  = renderableToPNGFile (chart 0.25) 320 240 "test5_small.png"
 main1 ["big"]    = renderableToPNGFile (chart 0.25) 800 600 "test5_big.png"
-main1 _          = renderableToWindow  (chart 1.00) 640 480 >> return undefined
 
 main = getArgs >>= main1
 
